@@ -223,7 +223,7 @@ class PlayList(Gtk.Box):
         self.pack_start(self.notebook, True, True, 0)
 
         # Use this trick to accelerate startup speed of app.
-        GLib.timeout_add(1500, self.init_ui)
+        GLib.timeout_add(1000, self.init_ui)
 
     def do_destroy(self):
         self.dump_playlists()
@@ -238,6 +238,8 @@ class PlayList(Gtk.Box):
         self.load_playlists()
         # dump playlists to dist every 5 minites
         GLib.timeout_add(300000, self.dump_playlists)
+        if self.app.conf['show-pls']:
+            self.app.popup_page(self.app_page)
         return False
 
     def dump_playlists(self):
@@ -613,7 +615,7 @@ class PlayList(Gtk.Box):
             return
         path = model.get_path(_iter)
         index = path.get_indices()[0]
-        disname, list_name, editable = model[path]
+        disname, list_name, editable, tooltip = model[path]
         liststore = self.tabs[list_name].liststore
 
         dialog = Gtk.Dialog(
