@@ -6,6 +6,7 @@
 
 import sys
 from gi.repository import Gdk
+from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gst
 from gi.repository import GstVideo
@@ -36,6 +37,7 @@ class PlayerBin(GObject.GObject):
             }
     xid = None
     bus_sync_sid = 0
+    audio_stream = 0
 
     def __init__(self):
         super().__init__()
@@ -61,11 +63,13 @@ class PlayerBin(GObject.GObject):
         self.disable_bus_sync()
         self.play()
 
-    def load_video(self, uri, xid):
+    def load_video(self, uri, xid, audio_stream):
+        print('load_video:', audio_stream)
         self.set_uri(uri)
         self.set_xid(xid)
         self.enable_bus_sync()
         self.play()
+        GLib.timeout_add(2000, self.set_current_audio, audio_stream)
 
     def destroy(self):
         self.quit()
@@ -104,6 +108,7 @@ class PlayerBin(GObject.GObject):
 
     def set_position(self, offset):
         self.seek(offset)
+        #self.set_current_audio(self.audio_stream)
 
     def seek(self, offset):
         self.playbin.seek_simple(
@@ -143,6 +148,18 @@ class PlayerBin(GObject.GObject):
     def get_mute(self):
         return self.playbin.get_property('mute')
 
+    def set_current_audio(self, audio_stream):
+        print('set_current_audio:', audio_stream)
+        if self.get_audios() <= audio_stream:
+            return
+        self.playbin.props.current_audio = audio_stream
+
+    def get_current_audio(self):
+        return self.playbin.props.current_audio
+
+    def get_audios(self):
+        return self.playbin.props.n_audio
+
     # private functions
     def enable_bus_sync(self):
         self.bus.enable_sync_message_emission()
